==> Botan-1.3.14.tgz: Botan-1.3.14/include/kdf.h <==
/*************************************************
* KDF Header File                                *
* (C) 1999-2004 The Botan Project                *
*************************************************/

#ifndef BOTAN_KDF_H__
#define BOTAN_KDF_H__

#include <botan/pk_util.h>

namespace Botan {

/*************************************************
* KDF1                                           *
*************************************************/
class KDF1 : public KDF
   {
   public:
      KDF1(const std::string&);
   private:
      OctetString derive(u32bit, const byte[], u32bit,
                         const byte[], u32bit) const;
      const std::string hash_name;
   };

/*************************************************
* KDF2                                           *
*************************************************/
class KDF2 : public KDF
   {
   public:
      KDF2(const std::string&);
   private:
      OctetString derive(u32bit, const byte[], u32bit,
                         const byte[], u32bit) const;
      const std::string hash_name;
   };

/*************************************************
* SSL3 PRF                                       *
*************************************************/
class SSL3_PRF : public KDF
   {
   private:
      OctetString derive(u32bit, const byte[], u32bit,
                                 const byte[], u32bit) const;
   };

/*************************************************
* TLS PRF                                        *
*************************************************/
class TLS_PRF : public KDF
   {
   private:
      OctetString derive(u32bit, const byte[], u32bit,
                                 const byte[], u32bit) const;
      OctetString P_hash(const std::string&, u32bit,
                         const byte[], u32bit,
                         const byte[], u32bit) const;
   };

/*************************************************
* X9.42 PRF                                      *
*************************************************/
class X942_PRF : public KDF
   {
   public:
      X942_PRF(const std::string&);
   private:
      OctetString derive(u32bit, const byte[], u32bit,
                                 const byte[], u32bit) const;
      std::string key_wrap_oid;
   };

}

#endif

==> Botan-1.4.2.tgz: Botan-1.4.2/include/kdf.h <==
/*************************************************
* KDF Header File                                *
* (C) 1999-2004 The Botan Project                *
*************************************************/

#ifndef BOTAN_KDF_H__
#define BOTAN_KDF_H__

#include <botan/pk_util.h>

namespace Botan {

/*************************************************
* KDF1                                           *
*************************************************/
class KDF1 : public KDF
   {
   public:
      KDF1(const std::string&);
   private:
      SecureVector<byte> derive(u32bit, const byte[], u32bit,
                                const byte[], u32bit) const;

      const std::string hash_name;
   };

/*************************************************
* KDF2                                           *
*************************************************/
class KDF2 : public KDF
   {
   public:

      KDF2(const std::string&);
   private:
      SecureVector<byte> derive(u32bit, const byte[], u32bit,
                                const byte[], u32bit) const;
      const std::string hash_name;
   };

/*************************************************
* SSL3 PRF                                       *
*************************************************/
class SSL3_PRF : public KDF
   {
   private:
      SecureVector<byte> derive(u32bit, const byte[], u32bit,
                                const byte[], u32bit) const;
   };

/*************************************************
* TLS PRF                                        *
*************************************************/
class TLS_PRF : public KDF
   {
   private:
      SecureVector<byte> derive(u32bit, const byte[], u32bit,
                                const byte[], u32bit) const;
      SecureVector<byte> P_hash(const std::string&, u32bit,
                                const byte[], u32bit,
                                const byte[], u32bit) const;
   };

/*************************************************
* X9.42 PRF                                      *
*************************************************/
class X942_PRF : public KDF
   {
   public:
      X942_PRF(const std::string&);
   private:
      SecureVector<byte> derive(u32bit, const byte[], u32bit,
                                const byte[], u32bit) const;

      std::string key_wrap_oid;
   };

}

#endif
